#
# spec file for package edict
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           edict
Version:        20180305
Release:        lp150.1.1
Summary:        The Japanese Dictionary Files from the EDRDG project
License:        CC-BY-SA-3.0 AND CC-BY-SA-4.0
Group:          System/I18n/Japanese
Url:            http://www.edrdg.org/jmdict/edict.html
# The files change daily, so we do not include their full URL here,
# but do see download_dicts.sh.
Source:         JMdict.gz
Source2:        edict.gz
Source3:        edict2u.gz
Source4:        enamdict.gz
Source5:        compdic.gz
Source6:        kanjidic2.xml.gz
Source7:        kanjidic.gz
Source8:        kanjd212.gz
Source9:        kradfile.gz
Source10:       radkfile.gz
Source97:       download_dicts.sh
Source98:       http://www.edrdg.org/edrdg/licence.html
Source99:       http://www.kanji.org/kanji/dictionaries/skip_permission.htm
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Provides:       locale(ja)

%description
The EDICT file is the outcome of a voluntary project to produce a
freely available Japanese-English Dictionary in machine readable form.
This project has been under way since early 1991, beginning with the
small original file included with the MOKE (Mark's Own Kanji Editor)
Japanese word processing package. It had reached a size of nearly
103,000 entries when it was split into two files: EDICT containing the
"normal" dictionary entries, and ENAMDICT containing names. Both files
are used by a number of software packages and thousands of users
worldwide. The EDICT file now has over 60,000 entries and the ENAMDICT
file has over 160,000 entries.

Meanwhile, there are also some additional dictionary files for special
purposes, COMPDIC, for example, for words from the computing and
communication field.

%prep 
# Make %%doc work
cp "%_sourcedir"/*.htm* .

%build

%install
d="%buildroot/%_datadir/edict"
mkdir -p "$d"
pushd "%_sourcedir/"
# Copy files which are in UTF-8 or XML directly
for i in JMdict.gz edict2u.gz kanjidic2.xml.gz; do
	gzip -cd "$i" >"$d/${i%.gz}"
done
# Transcode EUC-JP files
for i in compdic.gz edict.gz enamdict.gz kanjd212.gz kanjidic.gz kradfile.gz radkfile.gz; do
	gzip -cd "$i" | iconv -f euc-jp -t utf-8 >"$d/${i%.gz}"
done
popd

%files
%defattr(-, root, root)
%doc licence.html skip_permission.htm
%_datadir/edict/

%changelog
* Mon Mar  5 2018 jengelh@inai.de
- Update to snapshot 20180305
  * No changelog recorded. About 6000 new dictionary entries.
* Thu Jul  6 2017 jengelh@inai.de
- Update to new daily snapshot release 20170706
  * More than 1500 new entries to edict; no specific changelog
    known
* Sat Nov 26 2016 jengelh@inai.de
- Update to new daily snapshot release 20161126
  * 10 dictionary files are now under CC-BY-SA,
  the rest with other licenses has been removed from this package.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant/obsolete tags/sections from specfile
  (cf. packaging guidelines)
* Mon Aug  7 2006 mfabian@suse.de
- update to latest versions. Updated dictionaries are
  edict, enamdict, kanjdic, kanjd212, and compdic.
* Wed Mar  1 2006 mfabian@suse.de
- add "Provides: locale(ja)".
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Feb  9 2005 mfabian@suse.de
- updated edict to EDICT 10DEC04 V04-003
- updated enamdict to ENAMDICT 05JAN05 V2005-01
- remove jddict, it has a problematic license.
* Wed Dec  8 2004 mfabian@suse.de
- update license files contained in the package documentation
  to the latest versions and reword "Copyright" file according to
  Jim Breen's "Sample Acknowledgement"
  http://www.csse.monash.edu.au/groups/edrdg/sample.html
- updated edict to EDICT 14AUG04 V04-002.
- updated kanjidic to 14AUG2004.
* Tue Aug 10 2004 mfabian@suse.de
- updated edict to EDICT 07JUN04 V04-001
- updated enamdict to ENAMDICT 13APR04 V2004-01
- updated kanjidic to 11MAR2004
- add COPYRIGHT-KANJIDIC-JACK-HALPERN file.
* Tue Feb 24 2004 hmacht@suse.de
- building as non-root
* Mon Aug 25 2003 mfabian@suse.de
- updated all dictionaries to their latest version:
  - edict updated to EDICT 19AUG03 V03-004
  - enamdict updated to ENAMDICT 19AUG03 V2003-02
  - kanjidic updated to 21JUL2003
- use UTF-8 versions of dictionaries when available,
  convert all others to UTF-8 with iconv.
* Fri Jun 13 2003 mfabian@suse.de
- add %%dir /usr/share/edict/ to file list.
* Fri May 16 2003 mfabian@suse.de
- don't install files which are not packaged.
* Sun Feb 16 2003 mfabian@suse.de
- updated all dictionaries to their latest version:
  - edict updated to EDICT 04FEB03 V03-001
  - enamdict updated to ENAMDICT 06DEC02 V2002-03
  - compdic updated to COMPDIC 24OCT02 V02-001
- added buddhdic (Buddhistic terms)
* Sat Aug 10 2002 mfabian@suse.de
- updated all dictionaries to their latest version:
  - edict updated to EDICT 25APR02 V02-001
  - enamdict updated to ENAMDICT 11JUL02 V2002-02
* Mon Mar 18 2002 mfabian@suse.de
- updated all dictionaries to their latest version:
  - compdic updated to COMPDIC 04DEC01 V01-002
  - edict updated to EDICT 28NOV01 V01-002
  - enamdict updated to ENAMDICT 22JUN01 V2001-01
  - kanjidic updated to 06FEB2002
  - aviation updated
- added a few dictionaries
  - ediclsd3 (EDICLSD3 24JAN97/Life Sciences Dictionary File)
  - engscidic (engineering and physical sciences)
  - lawgledt (University of Washington Japanese-English
    Legal Glossary)
  - stardict (26JAN01 V01-001/Dictionary of Constellations)
* Mon Oct 30 2000 mfabian@suse.de
- added rpm group tag
* Mon Sep 11 2000 mfabian@suse.de
- remove %%{?suse_update_config}, it is not needed and makes the
  build fail on 6.4K-i386
* Fri Sep  8 2000 mfabian@suse.de
- new package edict-20000827
